SLiCAP.py — SLiCAP 4.0.7 documentation

# SLiCAP.py

Main module for running SLiCAP from a console or from within a Python IDE.

When working with Jupyter notebooks the main imort module is SLiCAPnotebook.py. It will import SLiCAP.py and some extra modules for displaying LaTeX, SVG and RST in the Jupyter notebooks.

Help()

  Opens the SLiCAP HTML documentation in the default browser.

  Example:

      >>> import SLiCAP as sl
      >>> # Display the SLiCAP HTML help in your default browser:
      >>> sl.Help()

initProject(name, notebook=False)

  Initializes a SLiCAP project.

  - Copies the directory structure from the templates subdirectory to the project directory in cases it has not yet been created.

  - Creates index.html in the html directory with the project name in the title bar

  - Compiles the system libraries

  - Creates or updates ‘SLiCAPconfigure.py’ in the project directory

  Parameters:

    name (str) – Name of the project: appears on the main html index page.

  Returns:

    None

  Return type:

    NoneType

  Example:

      >>> import SLiCAP as sl
      >>> # At the first run it will create a 'SLiCAP.ini' file in the SLiCAP
      >>> # home folder:  '~/SLiCAP/'.
      >>> # To this end it searches for installed applications.
      >>> # Under MSwindows this may take a while.
      >>> sl.initProject('my first SLiCAP project')
      >>> # At the first run this will create a 'SLiCAP.ini' file in the SLiCAP
      >>> # project folder:  './'. Once created it will only reset some values.
      >>> # This function also resets the netlist parser and (re)creates the
      >>> # system library objects.
      >>> sl.ini.dump()
      >>> # Prints the SLiCAP global settings obtained from both ini files.